==> ejc-jltest-api-3.0.0-20240330.065037-150-sources.jar: com/ejianc/business/jltest/orgtest/vo/DangeraDetailVO.java <==
package com.ejianc.business.jltest.orgtest.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 重大事故隐患判定明细A
 *
 * @author generator
 *
 */
public class DangeraDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long dangeraId; // 主表主键ID
    private String detailCode; // 隐患编号
    private Long detailCategory; // 类别
    private String detailManage; // 管理环节
    private String hiddenTrouble; // 隐患内容
    private String selfExamination; // 自查情况
    private String judgmentResults; // 判定结果
    private String detailMemo; // 备注


    public Long getDangeraId() {
        return dangeraId;
    }

    public void setDangeraId(Long dangeraId) {
        this.dangeraId = dangeraId;
    }
    public String getDetailCode() {
        return detailCode;
    }

    public void setDetailCode(String detailCode) {
        this.detailCode = detailCode;
    }

    //@ReferSerialTransfer(referCode = "support-defdoc")
    @ReferSerialTransfer(referCode = "test_type")
    public Long getDetailCategory() {
        return detailCategory;
    }
    @ReferDeserialTransfer
    public void setDetailCategory(Long detailCategory) {
        this.detailCategory = detailCategory;
    }

    public String getDetailManage() {
        return detailManage;
    }

    public void setDetailManage(String detailManage) {
        this.detailManage = detailManage;
    }
    public String getHiddenTrouble() {
        return hiddenTrouble;
    }

    public void setHiddenTrouble(String hiddenTrouble) {
        this.hiddenTrouble = hiddenTrouble;
    }
    public String getSelfExamination() {
        return selfExamination;
    }

    public void setSelfExamination(String selfExamination) {
        this.selfExamination = selfExamination;
    }
    public String getJudgmentResults() {
        return judgmentResults;
    }

    public void setJudgmentResults(String judgmentResults) {
        this.judgmentResults = judgmentResults;
    }
    public String getDetailMemo() {
        return detailMemo;
    }

    public void setDetailMemo(String detailMemo) {
        this.detailMemo = detailMemo;
    }

}

==> ejc-jltest-api-3.0.0-20240419.015833-159-sources.jar: com/ejianc/business/jltest/orgtest/vo/DangeraDetailVO.java <==
package com.ejianc.business.jltest.orgtest.vo;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 重大事故隐患判定明细A
 *
 * @author generator
 *
 */
public class DangeraDetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;

    private Long dangeraId; // 主表主键ID
    private String detailCode; // 隐患编号
    private Long detailCategory; // 类别
    private String detailManage; // 管理环节
    private String hiddenTrouble; // 隐患内容
    private String selfExamination; // 自查情况
    private String judgmentResults; // 判定结果
    private String detailMemo; // 备注


    public Long getDangeraId() {
        return dangeraId;
    }

    public void setDangeraId(Long dangeraId) {
        this.dangeraId = dangeraId;
    }
    public String getDetailCode() {
        return detailCode;
    }

    public void setDetailCode(String detailCode) {
        this.detailCode = detailCode;
    }

    @ReferSerialTransfer(referCode = "support-defdoc")
    //@ReferSerialTransfer(referCode = "test_type")
    public Long getDetailCategory() {
        return detailCategory;
    }
    @ReferDeserialTransfer
    public void setDetailCategory(Long detailCategory) {
        this.detailCategory = detailCategory;
    }

    public String getDetailManage() {
        return detailManage;
    }

    public void setDetailManage(String detailManage) {
        this.detailManage = detailManage;
    }
    public String getHiddenTrouble() {
        return hiddenTrouble;
    }

    public void setHiddenTrouble(String hiddenTrouble) {
        this.hiddenTrouble = hiddenTrouble;
    }
    public String getSelfExamination() {
        return selfExamination;
    }

    public void setSelfExamination(String selfExamination) {
        this.selfExamination = selfExamination;
    }
    public String getJudgmentResults() {
        return judgmentResults;
    }

    public void setJudgmentResults(String judgmentResults) {
        this.judgmentResults = judgmentResults;
    }
    public String getDetailMemo() {
        return detailMemo;
    }

    public void setDetailMemo(String detailMemo) {
        this.detailMemo = detailMemo;
    }

}
